@@ -26,6 +26,9 @@
 #'   \item Modelos 4 e 5: as primeiras colunas precisam ter a
 #'   informacao do fator A, fator B, repeticao/bloco, e posteriormente, as
 #'   variaveis respostas.
+#'   \item Modelos 6 e 7: as primeiras colunas precisam ter a
+#'   informacao do fator A, fator B, fator C, repeticao/bloco, e posteriormente, as
+#'   variaveis respostas.
 #'   }
 #' @param Modelo Valor numerico indicando o delineamento:
 #'  \itemize{
@@ -33,8 +36,10 @@
 #' \item 2 = Delineamento em blocos casualizados (DBC)
 #' \item 3 = Delineamento em quadrado
 #'   latino (DQL)
-#'   \item 4 = Esquema fatorial em DIC
-#'   \item 5 = Esquema fatorial em DBC
+#'   \item 4 = Esquema fatorial duplo em DIC
+#'   \item 5 = Esquema fatorial duplo em DBC
+#'   \item 6 = Esquema fatorial triplo em DIC
+#'   \item 7 = Esquema fatorial triplo em DBC
 #'   }
 #' @param Fator Indica qual fator deve ser estudado na representacao grafica. Tal
 #' decisao pode ser feita baseando na significancia da manova. Esse objeto deve receber:
@@ -45,7 +50,15 @@
 #' \item "B" = Para obter a presentacao grafica apenas dos niveis do fator B em caso
 #' de esquema fatorial (Design 4 ou 5)
 #' \item "A:B" = Para obter a presentacao grafica de todos os tratamentos (combinacoes
-#' entre os niveis do fator A e B) em caso de esquema fatorial (Design 4 ou 5)
+#' entre os niveis do fator A e B) em caso de esquema fatorial (Design 4, 5, 6 ou 7)
+#' \item "A:C" = Para obter a presentacao grafica de todos os tratamentos (combinacoes
+#' entre os niveis do fator A e C) em caso de esquema fatorial (Design 6 ou 7)
+#' \item "B:C" = Para obter a presentacao grafica de todos os tratamentos (combinacoes
+#' entre os niveis do fator B e C) em caso de esquema fatorial (Design 6 ou 7)
+#' \item "A:B:C" = Para obter a presentacao grafica de todos os tratamentos (combinacoes
+#' entre os niveis do fator A, B e C) em caso de esquema fatorial (Design 6 ou 7)
+
+
 #'   }
 #' @param xlab nome do eixo x do grafico de variaveis canonicas
 #' @param ylab nome do eixo y do grafico de variaveis canonicas
@@ -69,7 +82,7 @@
 #'      }
 #' @param Perc  Valor entre 0 e 1 indicando o recuo dos eixos.
 #' @return A funcao retorna resultados associados as variaveis canonicas.
-#' @seealso /code{/link{lm}}, /code{/link{manova}}
+#' @seealso \code{\link{lm}}, \code{\link{manova}}
 #' @references
 #' PlayList "Curso de Analise Multivariada":
 #'  https://www.youtube.com/playlist?list=PLvth1ZcREyK72M3lFl7kBaHiVh5W53mlR
@@ -93,18 +106,36 @@
 #' #Delineamento em quadrado latino (DQL)
 #' data(Dados.DQL)
 #' VariaveisCanonicas(Dados.DQL,3)
-#' #Esquema fatorial em DIC
+#'
+#' #Esquema fatorial duplo em DIC
 #' data(Dados.Fat2.DIC)
 #' VariaveisCanonicas(Dados.Fat2.DIC,4,Fator="A:B")
 #' VariaveisCanonicas(Dados.Fat2.DIC,4,Fator="A")
 #' VariaveisCanonicas(Dados.Fat2.DIC,4,Fator="B")
 #'
-#' #Esquema fatorial em DBC
+#' #Esquema fatorial duplo em DBC
 #' data(Dados.Fat2.DBC)
 #' VariaveisCanonicas(Dados.Fat2.DBC,5,Fator="A:B")
 #' VariaveisCanonicas(Dados.Fat2.DBC,5,Fator="A")
 #' VariaveisCanonicas(Dados.Fat2.DBC,5,Fator="B")
+#'
+#'
+#' #Esquema fatorial triplo em DIC
+#' data(Dados.Fat3.DIC)
+#' VariaveisCanonicas(Dados.Fat3.DIC,6,Fator="A:B")
+#' VariaveisCanonicas(Dados.Fat3.DIC,6,Fator="A")
+#' VariaveisCanonicas(Dados.Fat3.DIC,6,Fator="B")
+#'
+#' #Esquema fatorial triplo em DBC
+#' data(Dados.Fat3.DBC)
+#' VariaveisCanonicas(Dados.Fat3.DBC,7,Fator="A:B")
+#' VariaveisCanonicas(Dados.Fat3.DBC,7,Fator="A")
+#' VariaveisCanonicas(Dados.Fat3.DBC,7,Fator="B")
+#'
+#'
+#'
 #'}
+#' @importFrom graphics barplot
 #' @export
 #' @exportS3Method print VariaveisCanonicas
 
@@ -133,7 +164,9 @@ print.VariaveisCanonicas=function(x, ...){
 
  cat("Importancia","\n")
  cat("Correlacao das caracteristicas com os escores das variaveis canonicas","\n")
- print(x$`Correlacoes (importancia relativa)`[,1:ncol(x$Escores)])
+ if(length(dim(x$Escores))>1){print(x$`Correlacoes (importancia relativa)`[,1:ncol(x$Escores)])}
+ if(length(dim(x$Escores))==1){print(x$`Correlacoes (importancia relativa)`[,1])}
+
 
  cat("__________________________________________________________________","\n")
 }
